@@ -411,7 +411,7 @@ def _random_partition(
                 "dataset itself."
             )
     else:
-        raise ValueError(f"Cannot interpret length parameter {first_split_length}.")
+        raise TypeError(f"Cannot interpret length parameter {first_split_length}.")
     [(X1, X2), (y1, y2)] = utils.random_partitions(
         arrays=[X, y], total_length=n1, desired_length=desired_length, seed=seed
     )
